# Tutorials

```{toctree}
:maxdepth: 1

external_modules
```


```{todo}
Currently there are few official tutorials for Torii, however due to it being a fork of [Amaranth](https://github.com/amaranth-lang/amaranth) the following tutorials written by the Amaranth community are a good place to start.

 * [Learning FPGA Design with nMigen](https://vivonomicon.com/2020/04/14/learning-fpga-design-with-nmigen/)by Vivonomicon;
 * ["I want to learn nMigen](https://github.com/kbob/nmigen-examples) by kbob;
 * [A tutorial for using Amaranth HDL](https://github.com/robertbaruch/amaranth-tutorial) by Robert Baruch.
 * [Graded exercises for Amaranth HDL](https://github.com/robertbaruch/amaranth-exercises) by Robert Baruch.
```
